==> koffice-1.90.tar.bz2: koffice-1.90/kpresenter/pgconfdia.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef PGCONFDIA_H
#define PGCONFDIA_H

#include <qdialog.h>
#include <qmap.h>

#include "global.h"

class QButtonGroup;
class QLabel;
class QPushButton;
class QVBox;
class QResizeEvent;
class QListView;
class KPresenterDoc;
class QRadioButton;
class QComboBox;
class QCheckBox;

/******************************************************************/
/* class PgConfDia                                                */
/******************************************************************/

class PgConfDia : public QDialog
{
    Q_OBJECT

public:

    // constructor - destructor
    PgConfDia( QWidget* parent, KPresenterDoc *doc, const char* name,
               bool infLoop, bool swMan, int pgNum,
               PageEffect pageEffect, PresSpeed presSpeed,
               PresentSlides presSlides, const QMap<int,bool> &selectedSlides );
    bool getInfinitLoop();
    bool getManualSwitch();
    PageEffect getPageEffect();
    PresSpeed getPresSpeed();
    PresentSlides getPresentSlides();
    QMap<int,bool> getSelectedSlides();

protected:
    void resizeEvent( QResizeEvent *e );

    QButtonGroup *general, *page, *slides;
    QCheckBox *infinitLoop, *manualSwitch;
    QRadioButton *slidesAll, *slidesCurrent, *slidesSelected;
    QLabel *label1, *label2, *label3, *label4;
    QPushButton *cancelBut, *okBut;
    QComboBox *effectCombo, *speedCombo;
    QVBox *back;
    QListView *lSlides;

public slots:
    void confDiaOk() { emit pgConfDiaOk(); }

protected slots:
    void presSlidesChanged( int );

signals:
    void pgConfDiaOk();

};

#endif

==> koffice-2.0.1.tar.bz2: koffice-2.0.1/kpresenter/pgconfdia.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef PGCONFDIA_H
#define PGCONFDIA_H

#include <qdialog.h>
#include <qmap.h>

#include "global.h"

class QButtonGroup;
class QLabel;
class QPushButton;
class QVBox;
class QResizeEvent;
class QListView;
class KPresenterDoc;
class QRadioButton;
class QComboBox;
class QCheckBox;

/******************************************************************/
/* class PgConfDia                                                */
/******************************************************************/

class PgConfDia : public QDialog
{
    Q_OBJECT

public:

    // constructor - destructor
    PgConfDia( QWidget* parent, KPresenterDoc *doc, const char* name,
               bool infLoop, bool swMan, int pgNum,
               PageEffect pageEffect, PresSpeed presSpeed );
    bool getInfinitLoop();
    bool getManualSwitch();
    PageEffect getPageEffect();
    PresSpeed getPresSpeed();

protected:
    void resizeEvent( QResizeEvent *e );

    QButtonGroup *general, *page, *slides;
    QCheckBox *infinitLoop, *manualSwitch;
    QRadioButton *slidesAll, *slidesCurrent, *slidesSelected;
    QLabel *label1, *label2, *label3, *label4;
    QPushButton *cancelBut, *okBut;
    QComboBox *effectCombo, *speedCombo;
    QVBox *back;
    QListView *lSlides;

public slots:
    void confDiaOk() { emit pgConfDiaOk(); }

protected slots:
    void presSlidesChanged( int );

signals:
    void pgConfDiaOk();

};

#endif
